@@ -12,7 +12,6 @@
 
 """Execution options."""
 
-from typing import Union
 
 from .utils import Unset, UnsetType, primitive_dataclass
 
@@ -21,11 +20,11 @@ from .utils import Unset, UnsetType, primitive_dataclass
 class ExecutionOptionsV2:
     """Execution options for V2 primitives."""
 
-    init_qubits: Union[UnsetType, bool] = Unset
+    init_qubits: UnsetType | bool = Unset
     r"""Whether to reset the qubits to the ground state for each shot. Default is ``True``.
     """
 
-    rep_delay: Union[UnsetType, float] = Unset
+    rep_delay: UnsetType | float = Unset
     r"""The repetition delay. This is the delay between a measurement and
     the subsequent quantum circuit. This is only supported on backends that have
     ``backend.dynamic_reprate_enabled=True``. It must be from the
