@@ -15,7 +15,9 @@
 import logging
 import warnings
 from datetime import datetime
-from typing import Dict, Callable, Optional, Union, List, Any, Type, Sequence, Tuple
+from typing import Any
+from collections.abc import Callable, Sequence
+from urllib.parse import quote
 
 from qiskit.providers.backend import BackendV2 as Backend
 from qiskit.providers.exceptions import QiskitBackendNotFoundError
@@ -60,19 +62,19 @@ class QiskitRuntimeService:
 
     def __init__(
         self,
-        channel: Optional[ChannelType] = None,
-        token: Optional[str] = None,
-        url: Optional[str] = None,
-        filename: Optional[str] = None,
-        name: Optional[str] = None,
-        instance: Optional[str] = None,
-        proxies: Optional[dict] = None,
-        verify: Optional[bool] = None,
-        private_endpoint: Optional[bool] = None,
-        url_resolver: Optional[Callable[[str, str, Optional[bool], str], str]] = None,
-        region: Optional[str] = None,
-        plans_preference: Optional[List[str]] = None,
-        tags: Optional[List[str]] = None,
+        channel: ChannelType | None = None,
+        token: str | None = None,
+        url: str | None = None,
+        filename: str | None = None,
+        name: str | None = None,
+        instance: str | None = None,
+        proxies: dict | None = None,
+        verify: bool | None = None,
+        private_endpoint: bool | None = None,
+        url_resolver: Callable[[str, str, bool | None, str], str] | None = None,
+        region: str | None = None,
+        plans_preference: list[str] | None = None,
+        tags: list[str] | None = None,
     ) -> None:
         """QiskitRuntimeService constructor.
 
@@ -85,9 +87,9 @@ class QiskitRuntimeService:
                 from qiskit_ibm_runtime import QiskitRuntimeService
 
                 service = QiskitRuntimeService(
-                    channel="ibm_quantum_platform",
+                    channel="ibm_quantum_platform", # optional
                     token="API_KEY",
-                    instance="CRN"
+                    instance="CRN" # recommended
                     )
 
         * Saving default acccount:
@@ -139,20 +141,24 @@ class QiskitRuntimeService:
         Args:
             Optional[ChannelType] channel: String that identifies the service platform. This is
                 set to ``ibm_quantum_platform`` by default, but can additionally take ``local``
-                and ``ibm_cloud`` as values.
+                and ``ibm_cloud`` as values. ``ibm_cloud`` is a legacy option and points to the same
+                path as ``ibm_quantum_platform``, the recommended value is `ibm_quantum_platform``.
                 If ``local`` is selected, the local testing mode will be used, and
                 primitive queries will run on a local simulator. For more details, check the
                 `Qiskit Runtime local testing mode
                 <https://quantum.cloud.ibm.com/docs/guides/local-testing-mode>`_  documentation.
                 For non-local modes, the channel is used to resolve the default API URL value.
                 ``ibm_cloud`` was the identifier for the legacy IBM Cloud platform, and
-                its url will be redirected to the new ``ibm_quantum_platform`` url.
+                its URL will be redirected to the new ``ibm_quantum_platform`` address.
             Optional[str] token: IBM Cloud API key. Providing an API key is required for IQP
                 authentication. If not provided explicitly, the default saved account will be
                 queried for this API key.
-            Optional[str] url: The API URL. Defaults to different values depending on the selected
-                channel:  https://quantum.cloud.ibm.com  (``ibm_quantum_platform``), or
-                https://quantum-computing.cloud.ibm.com (``ibm_cloud``).
+            Optional[str] url: Base API URL. Defaults to ``https://cloud.ibm.com`` for non-local channels
+                accessing the IBM Quantum Platform (e.g., ``ibm_quantum_platform``, ``ibm_cloud``).
+                This URL is processed by a ``url_resolver`` to route requests to the correct
+                service entrypoint. If you provide a custom ``url``, you must also supply a
+                matching ``url_resolver``. The default resolver rewrites the base URL to
+                ``https://quantum.cloud.ibm.com/api/v[x]``.
             Optional[str] filename: Full path of the file where the account is created.
                 Default: _DEFAULT_ACCOUNT_CONFIG_JSON_FILE.
             Optional[str] name: Name of the account to load from file.
@@ -168,7 +174,8 @@ class QiskitRuntimeService:
                 authentication)
             Optional[bool] verify: Whether to verify the server's TLS certificate.
             Optional[bool] private_endpoint: Connect to private API URL.
-            Optional[Callable] url_resolver: Function used to resolve the runtime url.
+            Optional[Callable] url_resolver: Function used to resolve the runtime URL. If not provided,
+                a default resolver will be used to access different service endpoints.
             Optional[str] region: Set a region preference for automatic instance selection.
                 This argument is **ignored** if an ``instance`` is specified.
                 Accepted values are ``us-east`` or ``eu-de``.
@@ -185,14 +192,15 @@ class QiskitRuntimeService:
                 instance selection. This argument is **ignored** if an ``instance`` is specified.
 
         Returns:
-            An instance of QiskitRuntimeService or QiskitRuntimeLocalService for local channel.
+            An instance of :class:`.QiskitRuntimeService` or :class:`.QiskitRuntimeLocalService` if local
+            channel is set.
 
         Raises:
             IBMInputValueError: If an input is invalid.
         """
         super().__init__()
-        self._all_instances: List[Dict[str, Any]] = []
-        self._saved_instances: List[str] = []
+        self._all_instances: list[dict[str, Any]] = []
+        self._saved_instances: list[str] = []
         self._account = self._discover_account(
             token=token,
             url=url,
@@ -220,12 +228,12 @@ class QiskitRuntimeService:
 
         self._channel = self._account.channel
         self._url_resolver = url_resolver
-        self._backend_configs: Dict[str, QasmBackendConfiguration] = {}
+        self._backend_configs: dict[str, QasmBackendConfiguration] = {}
 
         self._default_instance = False
         self._active_api_client = RuntimeClient(self._client_params)
-        self._backends_list: List[Dict[str, Any]] = []
-        self._backend_instance_groups: List[Dict[str, Any]] = []
+        self._backends_list: list[dict[str, Any]] = []
+        self._backend_instance_groups: list[dict[str, Any]] = []
         self._region = region or self._account.region
         self._plans_preference = plans_preference or self._account.plans_preference
         self._tags = tags or self._account.tags
@@ -276,7 +284,7 @@ class QiskitRuntimeService:
             for inst, _ in instance_backends:
                 self._get_or_create_cloud_client(inst)
 
-    def _discover_backends_from_instance(self, instance: str) -> List[str]:
+    def _discover_backends_from_instance(self, instance: str) -> list[str]:
         """Retrieve all backends from the given instance."""
         # TODO refactor this, this is the slowest part
         # ntc 5779 would make things a lot faster - get list of backends
@@ -357,14 +365,14 @@ class QiskitRuntimeService:
 
     def _discover_account(
         self,
-        token: Optional[str] = None,
-        url: Optional[str] = None,
-        instance: Optional[str] = None,
-        channel: Optional[ChannelType] = None,
-        filename: Optional[str] = None,
-        name: Optional[str] = None,
-        proxies: Optional[ProxyConfiguration] = None,
-        verify: Optional[bool] = None,
+        token: str | None = None,
+        url: str | None = None,
+        instance: str | None = None,
+        channel: ChannelType | None = None,
+        filename: str | None = None,
+        name: str | None = None,
+        proxies: ProxyConfiguration | None = None,
+        verify: bool | None = None,
     ) -> Account:
         """Discover account for ibm_cloud and ibm_quantum_platform channels."""
         account = None
@@ -465,7 +473,7 @@ class QiskitRuntimeService:
             )
 
     @staticmethod
-    def _check_api_version(params: ClientParameters) -> Dict[str, Union[bool, str]]:
+    def _check_api_version(params: ClientParameters) -> dict[str, bool | str]:
         """Check the version of the remote server in a set of client parameters for all channels.
 
         Args:
@@ -479,7 +487,7 @@ class QiskitRuntimeService:
 
     def _get_api_client(
         self,
-        instance: Optional[str] = None,
+        instance: str | None = None,
     ) -> RuntimeClient:
         """Return the saved api client for a given instance for all channels.
         If no instance is provided, return the current active api client.
@@ -513,16 +521,16 @@ class QiskitRuntimeService:
     # pylint: disable=arguments-differ
     def backends(
         self,
-        name: Optional[str] = None,
-        min_num_qubits: Optional[int] = None,
-        instance: Optional[str] = None,
-        dynamic_circuits: Optional[bool] = None,
-        filters: Optional[Callable[["ibm_backend.IBMBackend"], bool]] = None,
+        name: str | None = None,
+        min_num_qubits: int | None = None,
+        instance: str | None = None,
+        dynamic_circuits: bool | None = None,
+        filters: Callable[["ibm_backend.IBMBackend"], bool] | None = None,
         *,
-        use_fractional_gates: Optional[bool] = False,
-        calibration_id: Optional[str] = None,
+        use_fractional_gates: bool | None = False,
+        calibration_id: str | None = None,
         **kwargs: Any,
-    ) -> List["ibm_backend.IBMBackend"]:
+    ) -> list["ibm_backend.IBMBackend"]:
         """Return all backends accessible via this account, subject to optional filtering.
 
         Args:
@@ -574,7 +582,7 @@ class QiskitRuntimeService:
             IBMInputValueError: If an input is invalid.
             QiskitBackendNotFoundError: If the backend is not in any instance.
         """
-        backends: List[IBMBackend] = []
+        backends: list[IBMBackend] = []
 
         unique_backends = set()
         instance_backends = self._resolve_cloud_instances(instance)
@@ -633,7 +641,7 @@ class QiskitRuntimeService:
             backend.options.use_fractional_gates = use_fractional_gates
         return filter_backends(backends, filters=filters, **kwargs)
 
-    def _resolve_cloud_instances(self, instance: Optional[str]) -> List[Tuple[str, List[str]]]:
+    def _resolve_cloud_instances(self, instance: str | None) -> list[tuple[str, list[str]]]:
         if instance:
             if not is_crn(instance):
                 instance = self._get_crn_from_instance_name(self._account, instance)
@@ -687,9 +695,9 @@ class QiskitRuntimeService:
     def _create_backend_obj(
         self,
         backend_name: str,
-        instance: Optional[str],
-        use_fractional_gates: Optional[bool],
-        calibration_id: Optional[str] = None,
+        instance: str | None,
+        use_fractional_gates: bool | None,
+        calibration_id: str | None = None,
     ) -> IBMBackend:
         """Given a backend configuration return the backend object.
 
@@ -750,7 +758,7 @@ class QiskitRuntimeService:
             )
         return None
 
-    def active_account(self) -> Optional[Dict[str, str]]:
+    def active_account(self) -> dict[str, str] | None:
         """Return the IBM Quantum account currently in use for the session.
 
         Returns:
@@ -760,9 +768,9 @@ class QiskitRuntimeService:
 
     @staticmethod
     def delete_account(
-        filename: Optional[str] = None,
-        name: Optional[str] = None,
-        channel: Optional[ChannelType] = None,
+        filename: str | None = None,
+        name: str | None = None,
+        channel: ChannelType | None = None,
     ) -> bool:
         """Delete a saved account from disk.
 
@@ -780,20 +788,20 @@ class QiskitRuntimeService:
 
     @staticmethod
     def save_account(
-        token: Optional[str] = None,
-        url: Optional[str] = None,
-        instance: Optional[str] = None,
-        channel: Optional[ChannelType] = None,
-        filename: Optional[str] = None,
-        name: Optional[str] = None,
-        proxies: Optional[dict] = None,
-        verify: Optional[bool] = None,
-        overwrite: Optional[bool] = False,
-        set_as_default: Optional[bool] = None,
-        private_endpoint: Optional[bool] = False,
-        region: Optional[RegionType] = None,
-        plans_preference: Optional[PlanType] = None,
-        tags: Optional[List[str]] = None,
+        token: str | None = None,
+        url: str | None = None,
+        instance: str | None = None,
+        channel: ChannelType | None = None,
+        filename: str | None = None,
+        name: str | None = None,
+        proxies: dict | None = None,
+        verify: bool | None = None,
+        overwrite: bool | None = False,
+        set_as_default: bool | None = None,
+        private_endpoint: bool | None = False,
+        region: RegionType | None = None,
+        plans_preference: PlanType | None = None,
+        tags: list[str] | None = None,
     ) -> None:
         """Save the account to disk for future use.
 
@@ -843,15 +851,15 @@ class QiskitRuntimeService:
             private_endpoint=private_endpoint,
             region=region,
             plans_preference=plans_preference,
-            tags=tags,
+            tags=tags,  # type: ignore[arg-type]
         )
 
     @staticmethod
     def saved_accounts(
-        default: Optional[bool] = None,
-        channel: Optional[ChannelType] = None,
-        filename: Optional[str] = None,
-        name: Optional[str] = None,
+        default: bool | None = None,
+        channel: ChannelType | None = None,
+        filename: str | None = None,
+        name: str | None = None,
     ) -> dict:
         """List the accounts saved on disk.
 
@@ -879,9 +887,9 @@ class QiskitRuntimeService:
     def backend(
         self,
         name: str,
-        instance: Optional[str] = None,
-        use_fractional_gates: Optional[bool] = False,
-        calibration_id: Optional[str] = None,
+        instance: str | None = None,
+        use_fractional_gates: bool | None = False,
+        calibration_id: str | None = None,
     ) -> Backend:
         """Return a single backend matching the specified filtering.
 
@@ -906,6 +914,7 @@ class QiskitRuntimeService:
 
         Raises:
             QiskitBackendNotFoundError: if no backend could be found.
+            IBMInputValueError: if fractional gates are requested but not supported by the backend.
         """
         backends = self.backends(
             name,
@@ -921,17 +930,27 @@ class QiskitRuntimeService:
                     "https://quantum.cloud.ibm.com/docs/en/guides/qpu-information#view-your-resources"
                 )
             raise QiskitBackendNotFoundError("No backend matches the criteria." + cloud_msg_url)
+
+        if use_fractional_gates:
+            basis_gates = backends[0].basis_gates
+            if "rzz" not in basis_gates:
+                # TODO suggest backends that support frac gates in error message
+                # via service.backends(use_fractional_gates=True)
+                raise IBMInputValueError(
+                    f"Backend '{name}' does not support fractional gates, "
+                    "but use_fractional_gates was set to True."
+                )
         return backends[0]
 
     def _run(
         self,
         program_id: str,
-        inputs: Dict,
-        options: Optional[Union[RuntimeOptions, Dict]] = None,
-        result_decoder: Optional[Union[Type[ResultDecoder], Sequence[Type[ResultDecoder]]]] = None,
-        session_id: Optional[str] = None,
-        start_session: Optional[bool] = False,
-        calibration_id: Optional[str] = None,
+        inputs: dict,
+        options: RuntimeOptions | dict | None = None,
+        result_decoder: type[ResultDecoder] | Sequence[type[ResultDecoder]] | None = None,
+        session_id: str | None = None,
+        start_session: bool | None = False,
+        calibration_id: str | None = None,
     ) -> RuntimeJobV2:
         """Execute the runtime program.
 
@@ -956,10 +975,11 @@ class QiskitRuntimeService:
             IBMRuntimeError: An error occurred running the program.
         """
 
-        qrt_options: RuntimeOptions = options
+        self._check_instance_usage()
+        qrt_options: RuntimeOptions = options  # type: ignore[assignment]
         if options is None:
             qrt_options = RuntimeOptions()
-        elif isinstance(options, Dict):
+        elif isinstance(options, dict):
             qrt_options = RuntimeOptions(**options)
 
         qrt_options.validate(channel=self.channel)
@@ -1047,18 +1067,18 @@ class QiskitRuntimeService:
 
     def jobs(
         self,
-        limit: Optional[int] = 10,
+        limit: int | None = 10,
         skip: int = 0,
-        backend_name: Optional[str] = None,
+        backend_name: str | None = None,
         pending: bool = None,
         program_id: str = None,
-        instance: Optional[str] = None,
-        job_tags: Optional[List[str]] = None,
-        session_id: Optional[str] = None,
-        created_after: Optional[datetime] = None,
-        created_before: Optional[datetime] = None,
+        instance: str | None = None,
+        job_tags: list[str] | None = None,
+        session_id: str | None = None,
+        created_after: datetime | None = None,
+        created_before: datetime | None = None,
         descending: bool = True,
-    ) -> List[RuntimeJobV2]:
+    ) -> list[RuntimeJobV2]:
         """Retrieve all runtime jobs, subject to optional filtering.
 
         Args:
@@ -1099,7 +1119,7 @@ class QiskitRuntimeService:
         if job_tags:
             validate_job_tags(job_tags)
 
-        job_responses = []  # type: List[Dict[str, Any]]
+        job_responses: list[dict[str, Any]] = []
         current_page_limit = limit or 20
         offset = skip
         while True:
@@ -1138,34 +1158,7 @@ class QiskitRuntimeService:
 
         return [self._decode_job(job) for job in job_responses]
 
-    def delete_job(self, job_id: str) -> None:
-        """(DEPRECATED) Delete a runtime job.
-
-        Note that this operation cannot be reversed.
-
-        Args:
-            job_id: ID of the job to delete.
-
-        Raises:
-            RuntimeJobNotFound: The job doesn't exist.
-            IBMRuntimeError: Method is not supported.
-        """
-
-        warnings.warn(
-            "The delete_job() method is deprecated and will be removed in a future release. "
-            "The new IBM Quantum Platform does not support deleting jobs.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-
-        try:
-            self._active_api_client.job_delete(job_id)
-        except RequestsApiError as ex:
-            if ex.status_code == 404:
-                raise RuntimeJobNotFound(f"Job not found: {ex.message}") from None
-            raise IBMRuntimeError(f"Failed to delete job: {ex}") from None
-
-    def usage(self) -> Dict[str, Any]:
+    def usage(self) -> dict[str, Any]:
         """Return usage information for the current active instance.
 
         Returns:
@@ -1181,7 +1174,27 @@ class QiskitRuntimeService:
             usage_dict["usage_remaining_seconds"] = usage_remaining
         return usage_dict
 
-    def _decode_job(self, raw_data: Dict) -> RuntimeJobV2:
+    def _check_instance_usage(self) -> None:
+        """Emit a warning if instance usage has been reached."""
+        usage_dict = self.usage()
+
+        if usage_dict.get("usage_limit_reached"):
+            if usage_dict.get("usage_limit_seconds") and usage_dict["usage_remaining_seconds"] <= 0:
+                warnings.warn(
+                    "This instance has met its usage limit. Workloads will not run until time is made "
+                    "available. Check "
+                    f"https://quantum.cloud.ibm.com/instances/{quote(self.active_instance(), safe='')} "
+                    "for more details."
+                )
+            else:
+                warnings.warn(
+                    "There is currently no more time available for this instance's plan on the account. "
+                    "Workloads will not run until time is made available. Check "
+                    f"https://quantum.cloud.ibm.com/instances/{quote(self.active_instance(), safe='')} "
+                    "for more details."
+                )
+
+    def _decode_job(self, raw_data: dict) -> RuntimeJobV2:
         """Decode job data received from the server.
 
         Args:
@@ -1218,48 +1231,11 @@ class QiskitRuntimeService:
             private=raw_data.get("private", False),
         )
 
-    def check_pending_jobs(self) -> None:
-        """(DEPRECATED) Check the number of pending jobs and wait for the oldest pending job if
-        the maximum number of pending jobs has been reached.
-        """
-
-        warnings.warn(
-            "The check_pending_jobs() method is deprecated and will be removed in a future release. "
-            "The new IBM Quantum Platform does not support this functionality.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-
-        try:
-            usage = self.usage().get("byInstance")[0]
-            pending_jobs = usage.get("pendingJobs")
-            max_pending_jobs = usage.get("maxPendingJobs")
-            if pending_jobs >= max_pending_jobs:
-                oldest_running = self.jobs(limit=1, descending=False, pending=True)
-                if oldest_running:
-                    logger.warning(
-                        "The pending jobs limit has been reached. "
-                        "Waiting for job %s to finish before submitting the next one.",
-                        oldest_running[0],
-                    )
-                    try:
-                        oldest_running[0].wait_for_final_state(timeout=300)
-
-                    except Exception as ex:  # pylint: disable=broad-except
-                        logger.debug(
-                            "An error occurred while waiting for job %s to finish: %s",
-                            oldest_running[0].job_id(),
-                            ex,
-                        )
-
-        except Exception as ex:  # pylint: disable=broad-except
-            logger.warning("Unable to retrieve open plan pending jobs details. %s", ex)
-
     def least_busy(
         self,
-        min_num_qubits: Optional[int] = None,
-        instance: Optional[str] = None,
-        filters: Optional[Callable[["ibm_backend.IBMBackend"], bool]] = None,
+        min_num_qubits: int | None = None,
+        instance: str | None = None,
+        filters: Callable[["ibm_backend.IBMBackend"], bool] | None = None,
         **kwargs: Any,
     ) -> ibm_backend.IBMBackend:
         """Return the least busy available backend.
@@ -1323,7 +1299,7 @@ class QiskitRuntimeService:
                 pass
         raise QiskitBackendNotFoundError("No backend matches the criteria.")
 
-    def instances(self) -> Sequence[Dict[str, Any]]:
+    def instances(self) -> Sequence[dict[str, Any]]:
         """Return a list that contains a series of dictionaries with the
             following instance identifiers per instance: "crn", "plan", "name".
 
